@@ -1,6 +1,6 @@
 package Crypt::Passwd::XS;
 
-our $VERSION = '0.507';
+our $VERSION = '0.600';
 
 require XSLoader;
 XSLoader::load( 'Crypt::Passwd::XS', $VERSION );
@@ -22,6 +22,9 @@ sub crypt {
     elsif ( substr( $salt, 0, 1 ) ne '$' ) {
         return unix_des_crypt( $password, $salt );
     }
+    elsif ( substr( $salt, 0, 6 ) eq '$apr1$' ) {
+        return apache_md5_crypt( $password, $salt );
+    }
     else {
 
         # Unimplemented hashing scheme
@@ -35,7 +38,7 @@ __END__
 
 =head1 NAME
 
-Crypt::Passwd::XS - Full XS implementation of common crypt() algorythms
+Crypt::Passwd::XS - Full XS implementation of common crypt() algorithms
 
 =head1 SYNOPSIS
 
@@ -59,6 +62,9 @@ salt prefix system for determinging the crypt type.
 The B<unix_md5_crypt()> function performs a MD5 crypt regardless of the salt
 prefix.
 
+The B<apache_md5_crypt()> function performs a APR1 crypt regardless of the salt
+prefix.
+
 The B<unix_des_crypt()> funtion performs a traditional DES crypt regardless of
 the salt prefix.
 
